@@ -1,4 +1,5 @@
 from enum import Enum, IntEnum, auto
+from dataclasses import dataclass
 
 
 class RuleExecutionStatus(Enum):
@@ -53,3 +54,21 @@ class AssetSourceType(Enum):
 
 DATA_QUALITY = 'DATA_QUALITY'
 RECONCILIATION = 'RECONCILIATION'
+
+# SDK_MIN_VERSION_SUPPORT should have the compatible version number as per torch. So even if SDK version number changes
+# but the compatibility with the torch doesn't break then SDK_MIN_VERSION_SUPPORT need not change.
+
+SDK_MIN_VERSION_SUPPORT = '2.2.0'
+
+
+@dataclass
+class SdkSupportedVersions:
+    maxVersion = None
+    minVersion = None
+
+    def __init__(self, maxVersion=None, minVersion=None, **kwargs):
+        self.maxVersion = maxVersion
+        self.minVersion = minVersion
+
+    def __repr__(self):
+        return f"SdkSupportedVersions({self.__dict__})"
\ No newline at end of file
